==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/ManagedRuleOverrideArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.ManagedRuleOverrideArgs.builder
import com.pulumi.azurenative.cdn.kotlin.enums.ActionType
import com.pulumi.azurenative.cdn.kotlin.enums.ManagedRuleEnabledState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines a managed rule group override setting.
 * @property action Describes the override action to be applied when rule matches.
 * @property enabledState Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
 * @property ruleId Identifier for the managed rule.
 */
public data class ManagedRuleOverrideArgs(
    public val action: Output<Either<String, ActionType>>? = null,
    public val enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null,
    public val ruleId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.ManagedRuleOverrideArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.ManagedRuleOverrideArgs =
        com.pulumi.azurenative.cdn.inputs.ManagedRuleOverrideArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enabledState(
                enabledState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ruleId(ruleId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ManagedRuleOverrideArgs].
 */
@PulumiTagMarker
public class ManagedRuleOverrideArgsBuilder internal constructor() {
    private var action: Output<Either<String, ActionType>>? = null

    private var enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null

    private var ruleId: Output<String>? = null

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("uiabvpyywjhbnoen")
    public suspend fun action(`value`: Output<Either<String, ActionType>>) {
        this.action = value
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("ppclqtlnmwisbira")
    public suspend fun enabledState(`value`: Output<Either<String, ManagedRuleEnabledState>>) {
        this.enabledState = value
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("wokpdydmgsacpvxk")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("fwwddlnchvttanjg")
    public suspend fun action(`value`: Either<String, ActionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("botfmmpgfdooefou")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("fjywkrbmprguiwvr")
    public fun action(`value`: ActionType) {
        val toBeMapped = Either.ofRight<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("dphtcvrqdlljtnab")
    public suspend fun enabledState(`value`: Either<String, ManagedRuleEnabledState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("imgqvtkeumtqgvtk")
    public fun enabledState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("leinklybvaibqmot")
    public fun enabledState(`value`: ManagedRuleEnabledState) {
        val toBeMapped = Either.ofRight<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("swbhlngfowqvjlgx")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    internal fun build(): ManagedRuleOverrideArgs = ManagedRuleOverrideArgs(
        action = action,
        enabledState = enabledState,
        ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/inputs/ManagedRuleOverrideArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.inputs

import com.pulumi.azurenative.cdn.inputs.ManagedRuleOverrideArgs.builder
import com.pulumi.azurenative.cdn.kotlin.enums.ActionType
import com.pulumi.azurenative.cdn.kotlin.enums.ManagedRuleEnabledState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Defines a managed rule group override setting.
 * @property action Describes the override action to be applied when rule matches.
 * @property enabledState Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
 * @property ruleId Identifier for the managed rule.
 */
public data class ManagedRuleOverrideArgs(
    public val action: Output<Either<String, ActionType>>? = null,
    public val enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null,
    public val ruleId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.cdn.inputs.ManagedRuleOverrideArgs> {
    override fun toJava(): com.pulumi.azurenative.cdn.inputs.ManagedRuleOverrideArgs =
        com.pulumi.azurenative.cdn.inputs.ManagedRuleOverrideArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enabledState(
                enabledState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ruleId(ruleId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ManagedRuleOverrideArgs].
 */
@PulumiTagMarker
public class ManagedRuleOverrideArgsBuilder internal constructor() {
    private var action: Output<Either<String, ActionType>>? = null

    private var enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null

    private var ruleId: Output<String>? = null

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("fgaofhresimkgjvr")
    public suspend fun action(`value`: Output<Either<String, ActionType>>) {
        this.action = value
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("kurouopmiyuvtomq")
    public suspend fun enabledState(`value`: Output<Either<String, ManagedRuleEnabledState>>) {
        this.enabledState = value
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("pspqxsutanqtrmvn")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("radmcgwjerdvypxd")
    public suspend fun action(`value`: Either<String, ActionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("gajtywqsekkrxnmq")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("vvudlyqxtqujhgyl")
    public fun action(`value`: ActionType) {
        val toBeMapped = Either.ofRight<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("fpavphqmariodtbn")
    public suspend fun enabledState(`value`: Either<String, ManagedRuleEnabledState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("nfbpdvquemxbylph")
    public fun enabledState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("pmjjumlktgyetjox")
    public fun enabledState(`value`: ManagedRuleEnabledState) {
        val toBeMapped = Either.ofRight<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("oxbswkmdyhcusywg")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    internal fun build(): ManagedRuleOverrideArgs = ManagedRuleOverrideArgs(
        action = action,
        enabledState = enabledState,
        ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
    )
}
